@@ -56,6 +56,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 		opt_attach_line_anchors ( false ),
 		opt_show_themes ( false ),
 		opt_show_langdefs ( false ),
+		opt_show_plugins (false),
 		opt_printindex ( false ),
 		opt_quiet ( false ),
 		opt_replacequotes ( false ),
@@ -67,6 +68,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 		opt_ordered_list ( false ),
 		opt_fnames_as_anchors ( false ),
 		opt_validate ( false ),
+		opt_number_wrapped_lines ( true ), //before the patch, this was always true, so by default it stays true.
 		opt_inline_css ( false ),
 		opt_enclose_pre ( false ),
 		opt_char_styles ( false ),
@@ -80,17 +82,17 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 {
 	enum Optcode
 	{
-		S_OPT_ADDCONFDIR = 256, S_OPT_ENCLOSE_PRE, S_OPT_FORCE_OUTPUT,
+		S_OPT_ENCLOSE_PRE = 256, S_OPT_FORCE_OUTPUT,
 		S_OPT_INLINE_CSS, S_OPT_KW_CASE,
-		S_OPT_PRINT_CONFIG, S_OPT_TEST_INPUT,
+		S_OPT_PRINT_CONFIG, S_OPT_TEST_INPUT, S_OPT_NO_NUMBER_WL,
 		S_OPT_SVG_WIDTH, S_OPT_SVG_HEIGHT, S_OPT_CLASSNAME, S_OPT_RTF_CHAR_STYLES,
 		S_OPT_SKIP_UNKNOWN,
 		S_OPT_COMPAT_DOC, S_OPT_COMPAT_NODOC, S_OPT_COMPAT_TAB, S_OPT_COMPAT_CSS,
 		S_OPT_COMPAT_OUTDIR, S_OPT_COMPAT_FAILSAFE,
 		S_OPT_COMPAT_SRCLANG, S_OPT_COMPAT_LINENUM, S_OPT_COMPAT_LINEREF,
-		S_OPT_CTAGS_FILE, S_OPT_PRETTY_SYMBOLS, S_OPT_EOL_DELIM_CR, S_OPT_START_NESTED,
+		S_OPT_PRETTY_SYMBOLS, S_OPT_EOL_DELIM_CR, S_OPT_START_NESTED,
 		S_OPT_PRINT_STYLE, S_OPT_NO_TRAILING_NL, S_OPT_PLUGIN, S_OPT_ABS_CFG_PATH,
-		S_OPT_PLUGIN_READFILE
+		S_OPT_PLUGIN_READFILE, S_LIST_SCRIPTS
 	};
 
 	const Arg_parser::Option options[] =
@@ -140,16 +142,15 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 		{ S_OPT_CLASSNAME, OPT_CLASSNAME,      Arg_parser::yes },
 		{ S_OPT_SVG_WIDTH,    OPT_SVG_WIDTH,    Arg_parser::yes  },
 		{ S_OPT_SVG_HEIGHT,   OPT_SVG_HEIGHT,   Arg_parser::yes  },
-		{ S_OPT_ADDCONFDIR,   OPT_ADDCONFDIR,   Arg_parser::yes },
 		{ S_OPT_ENCLOSE_PRE,  OPT_ENCLOSE_PRE,  Arg_parser::no  },
 		{ S_OPT_FORCE_OUTPUT, OPT_FORCE_OUTPUT, Arg_parser::no  },
 		{ S_OPT_INLINE_CSS,   OPT_INLINE_CSS,   Arg_parser::no  },
 		{ S_OPT_KW_CASE,      OPT_KW_CASE,      Arg_parser::yes },
 		{ S_OPT_PRINT_CONFIG, OPT_PRINT_CONFIG, Arg_parser::no  },
 		{ S_OPT_TEST_INPUT,   OPT_TEST_INPUT,   Arg_parser::no  },
+		{ S_OPT_NO_NUMBER_WL, OPT_NO_NUMBER_WL, Arg_parser::no  },
 		{ S_OPT_RTF_CHAR_STYLES, OPT_RTF_CHAR_STYLES, Arg_parser::no  },
 		{ S_OPT_SKIP_UNKNOWN, OPT_SKIP_UNKNOWN, Arg_parser::yes },
-		{ S_OPT_CTAGS_FILE,   OPT_CTAGS_FILE, Arg_parser::maybe },
 		{ S_OPT_START_NESTED,   OPT_START_NESTED,   Arg_parser::yes },
 		{ S_OPT_COMPAT_DOC,   OPT_COMPAT_DOC, Arg_parser::no },
 		{ S_OPT_COMPAT_NODOC, OPT_COMPAT_NODOC, Arg_parser::no },
@@ -167,6 +168,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 		{ S_OPT_PLUGIN, OPT_PLUGIN, Arg_parser::yes },
 		{ S_OPT_PLUGIN_READFILE, OPT_PLUGIN_READFILE, Arg_parser::yes },
 		{ S_OPT_ABS_CFG_PATH, OPT_ABS_CFG_PATH,  Arg_parser::yes},
+		{ S_LIST_SCRIPTS, OPT_LIST_SCRIPTS,  Arg_parser::yes},
 
 		{ 0,                  0,                Arg_parser::no  }
 	};
@@ -207,6 +209,8 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 					outputType = highlight::SVG;
 				else if ( tmp == "bbcode" )
 					outputType = highlight::BBCODE;
+				else if ( tmp == "odt" )
+					outputType = highlight::ODTFLAT;
 				else
 					outputType = highlight::HTML;
 				}
@@ -351,9 +355,6 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 			case S_OPT_SVG_HEIGHT:
 				svg_height = arg;
 				break;
-			case S_OPT_ADDCONFDIR:
-				additionalConfigDir = validateDirPath ( arg );
-				break;
 			case S_OPT_ENCLOSE_PRE:
 				opt_enclose_pre=true;
 				break;
@@ -382,15 +383,15 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 			case S_OPT_TEST_INPUT:
 				opt_validate=true;
 				break;
+			case S_OPT_NO_NUMBER_WL:
+				opt_number_wrapped_lines=false;
+				break;
 			case S_OPT_RTF_CHAR_STYLES:
 				opt_char_styles=true;
 				break;
 			case S_OPT_SKIP_UNKNOWN:
 				skipArg=arg;
 				break;
-			case S_OPT_CTAGS_FILE:
-				ctagsFile = ( arg.empty() ) ? "tags" :arg;
-				break;
 			case S_OPT_PLUGIN:
 				userPlugins.push_back(arg);
 				break;
@@ -430,6 +431,12 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 				else if (arg.find(".theme")!=string::npos) absThemePath=arg;
 				else cerr << "highlight: unknown config file type" << endl;
 				break;
+			case S_LIST_SCRIPTS:
+				opt_show_langdefs=(arg=="syntax" || arg=="langs");
+				opt_show_themes=(arg=="themes");
+				opt_show_plugins=(arg=="plugins");
+				break;
+			  
 			default:
 				cerr << "highlight: option parsing failed" << endl;
 		}
@@ -604,6 +611,7 @@ string CmdLineOptions::getOutFileSuffix() const
 		case highlight::ANSI:  return ".ansi";
 		case highlight::XTERM256: return ".xterm";
 		case highlight::BBCODE: return ".bbcode";
+		case highlight::ODTFLAT: return ".fodt";
 		default:    return ".html";
 	}
 }
@@ -624,6 +632,10 @@ bool CmdLineOptions::showLangdefs() const
 {
 	return opt_show_langdefs;
 }
+bool CmdLineOptions::showPlugins() const
+{
+	return opt_show_plugins;
+}
 bool CmdLineOptions::outDirGiven() const
 {
 	return !outFilename.empty();
@@ -668,10 +680,6 @@ string CmdLineOptions::getIndentScheme() const
 	return StringTools::change_case ( indentScheme );
 }
 
-const string &CmdLineOptions::getAdditionalConfDir() const
-{
-	return additionalConfigDir;
-}
 const string &CmdLineOptions::getSyntax() const
 {
 	return syntax;
@@ -720,6 +728,10 @@ bool CmdLineOptions::validateInput() const
 {
 	return opt_validate;
 }
+bool CmdLineOptions::numberWrappedLines() const
+{
+	return opt_number_wrapped_lines;
+}
 bool CmdLineOptions::inlineCSS() const
 {
 	return opt_inline_css;
@@ -736,10 +748,7 @@ bool CmdLineOptions::disableTrailingNL() const
 {
 	return opt_no_trailing_nl;
 }
-const string &CmdLineOptions::getConfigFilePath() const
-{
-	return configFilePath;
-}
+
 
 const string& CmdLineOptions::getDocumentTitle() const
 {
@@ -802,10 +811,6 @@ const string& CmdLineOptions::getClassName() const
 	return className ;
 }
 
-const string& CmdLineOptions::getTagsFile() const
-{
-	return ctagsFile;
-}
 const string& CmdLineOptions::getStartNestedLang() const
 {
 	return startNestedLang;
