@@ -44,7 +44,6 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "enums.h"
 
 #define OPT_OUTFORMAT      "out-format"
-#define OPT_ADDCONFDIR     "add-config-dir"
 #define OPT_ANCHORS        "anchors"
 #define OPT_ANCHOR_FN      "anchor-filename"
 #define OPT_ANCHOR_PFX     "anchor-prefix"
@@ -72,6 +71,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #define OPT_LINE_LEN       "line-length"
 #define OPT_LISTLANGS      "list-langs"
 #define OPT_LISTTHEMES     "list-themes"
+#define OPT_LIST_SCRIPTS   "list-scripts"
 #define OPT_LNR_LEN        "line-number-length"
 #define OPT_LNR_START      "line-number-start"
 #define OPT_ORDERED_LIST   "ordered-list"
@@ -95,7 +95,6 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #define OPT_SVG_WIDTH      "width"
 #define OPT_SVG_HEIGHT     "height"
 #define OPT_SKIP_UNKNOWN   "skip"
-#define OPT_CTAGS_FILE     "ctags-file"
 #define OPT_PRETTY_SYMBOLS "pretty-symbols"
 #define OPT_EOL_DELIM_CR   "delim-cr"
 #define OPT_START_NESTED   "start-nested"
@@ -104,6 +103,8 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #define OPT_PLUGIN         "plug-in"
 #define OPT_ABS_CFG_PATH   "config-file"
 #define OPT_PLUGIN_READFILE  "plug-in-read"
+#define OPT_NO_NUMBER_WL   "wrap-no-numbers"
+#define OPT_USE_NBSP       "nbsp"
 
 // Improve CLI option compatibility with GNU source-highlight
 #define OPT_COMPAT_DOC       "doc"
@@ -203,6 +204,9 @@ class CmdLineOptions
 		/** \return True if list of installed language definitions should be printed*/
 		bool showLangdefs() const;
 
+		/** \return True if list of installed language definitions should be printed*/
+		bool showPlugins() const;
+		
 		/** \return True if loutput directory is given*/
 		bool outDirGiven() const;
 
@@ -224,13 +228,6 @@ class CmdLineOptions
 		/** \return Data directory*/
 		const string &getDataDir() const;
 
-
-		/** \return Additional config data directory*/
-		const string &getAdditionalConfDir() const;
-
-		/** \return  path of user config file*/
-		const string &getConfigFilePath() const;
-
 		/** \return True if language syntax is given*/
 		bool syntaxGiven() const;
 
@@ -252,9 +249,6 @@ class CmdLineOptions
 		/** \return List of input file names*/
 		const vector <string> & getInputFileNames() const;
 
-		/** \return Map of marked lines*/
-// 		const map <int,string> &getMarkLines();
-
 		/** \return indentation and reformatting scheme*/
 		string getIndentScheme() const;
 
@@ -281,6 +275,9 @@ class CmdLineOptions
 
 		/** \return True if line numbers should be replaced by ordered list (HTML) */
 		bool orderedList() const;
+		
+		/** \return True if spaces should be replaced by &nbsp; (HTML) */
+		//bool useNonBreakingSpace() const;
 
 		/** \return True if a base font has been given */
 		bool hasBaseFont() const ;
@@ -288,6 +285,9 @@ class CmdLineOptions
 		/** \return True if input should be validated */
 		bool validateInput() const ;
 
+		/** \return True if wrapped lines should get unique numbers */
+		bool numberWrappedLines() const ;
+
 		/** \return True if CSS should be outputted within tag elements */
 		bool inlineCSS() const ;
 
@@ -315,9 +315,6 @@ class CmdLineOptions
 		/** \return class name */
 		const string& getClassName() const ;
 
-		/** \return ctags file name */
-		const string& getTagsFile() const ;
-
 		const vector <string> &getPluginPaths() const;
 
 		/** \return True if trailing nl should be omitted */
@@ -378,7 +375,7 @@ class CmdLineOptions
 		// name of file to be included in external style file
 		styleInFilename,
 		// used to define data directories at runtime
-		dataDir, additionalConfigDir;
+		dataDir;
 		// name of indenation scheme
 		string indentScheme,
 		pageSize, startNestedLang;
@@ -387,7 +384,6 @@ class CmdLineOptions
 		string docTitle, className;
 		string skipArg;
 		string svg_height, svg_width;
-		string ctagsFile;
 		string absThemePath, absLangPath;
 
 		bool opt_syntax;
@@ -403,6 +399,7 @@ class CmdLineOptions
 		bool opt_attach_line_anchors;
 		bool opt_show_themes;
 		bool opt_show_langdefs;
+		bool opt_show_plugins;
 		bool opt_asformat_output;
 		bool opt_printindex;
 		bool opt_quiet;
@@ -415,6 +412,7 @@ class CmdLineOptions
 		bool opt_ordered_list;
 		bool opt_fnames_as_anchors;
 		bool opt_validate;
+		bool opt_number_wrapped_lines;
 		bool opt_inline_css;
 		bool opt_enclose_pre;
 		bool opt_char_styles;
@@ -425,7 +423,7 @@ class CmdLineOptions
 
 		string anchorPrefix;
 		string helpLang, encodingName;
-		string configFilePath;
+
 		string pluginPath, pluginReadFilePath;
 
 		/** list of all input file names */
