@@ -81,7 +81,7 @@ namespace Help
 		cout<<" -F, --reformat=<style>         reformats and indents output in given style\n";
 		cout<<"                                  <style>=[allman, banner, gnu,\n";
 		cout<<"                                  horstmann, java, kr, linux, otbs,\n";
-		cout<<"                                  stroustrup, whitesmith]\n";
+		cout<<"                                  stroustrup, whitesmith, google, pico, lisp]\n";
 		cout<<" -I, --include-style            include style definition\n";
 		cout<<" -J, --line-length=<num>        line length before wrapping (see -W, -V)\n";
 		cout<<" -j, --line-number-length=<num> line number width incl. left padding\n";
