@@ -49,7 +49,7 @@ void HLCmdLineApp::printVersionInfo()
          << "\n Copyright (C) 2002-2013 Andre Simon <andre.simon1 at gmx.de>"
          << "\n\n Argparser class"
          << "\n Copyright (C) 2006-2008 Antonio Diaz Diaz <ant_diaz at teleline.es>"
-         << "\n\n Artistic Style Classes (2.03)"
+         << "\n\n Artistic Style Classes (2.04)"
          << "\n Copyright (C) 2006-2013 by Jim Pattee <jimp03 at email.com>"
          << "\n Copyright (C) 1998-2002 by Tal Davidson"
          << "\n\n Diluculum Lua wrapper (1.0)"
@@ -220,8 +220,12 @@ string HLCmdLineApp::getFileSuffix(const string& fileName)
 {
     size_t ptPos=fileName.rfind(".");
     size_t psPos = fileName.rfind ( Platform::pathSeparator );
-    return (ptPos == string::npos || (psPos!=string::npos && psPos>ptPos)) ? "" : fileName.substr(ptPos+1,
-            fileName.length());
+    if (ptPos == string::npos){
+     return  (psPos==string::npos) ? fileName : fileName.substr(psPos+1, fileName.length());
+    }
+    //return (ptPos == string::npos || (psPos!=string::npos && psPos>ptPos)) ? "" : fileName.substr(ptPos+1, fileName.length()); 
+    return (psPos!=string::npos && psPos>ptPos) ? "" : fileName.substr(ptPos+1, fileName.length()); 
+  
 }
 
 bool HLCmdLineApp::loadFileTypeConfig ( const string& name, StringMap* extMap, StringMap* shebangMap )
