@@ -25,12 +25,12 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  */
 
-#include "../../include/astyle/astyle.h"
+#include "astyle/astyle.h"
 #include <algorithm>
 
 
-namespace astyle
-{
+namespace astyle {
+
 const string ASResource::AS_IF = string("if");
 const string ASResource::AS_ELSE = string("else");
 const string ASResource::AS_FOR = string("for");
@@ -45,6 +45,8 @@ const string ASResource::AS_STRUCT = string("struct");
 const string ASResource::AS_UNION = string("union");
 const string ASResource::AS_INTERFACE = string("interface");
 const string ASResource::AS_NAMESPACE = string("namespace");
+const string ASResource::AS_END = string("end");
+const string ASResource::AS_SELECTOR = string("selector");
 const string ASResource::AS_EXTERN = string("extern");
 const string ASResource::AS_ENUM = string("enum");
 const string ASResource::AS_PUBLIC = string("public");
@@ -121,7 +123,7 @@ const string ASResource::AS_LAMBDA = string("=>");            // C# lambda expre
 const string ASResource::AS_ARROW = string("->");
 const string ASResource::AS_AND = string("&&");
 const string ASResource::AS_OR = string("||");
-const string ASResource::AS_COLON_COLON = string("::");
+const string ASResource::AS_SCOPE_RESOLUTION = string("::");
 
 const string ASResource::AS_PLUS = string("+");
 const string ASResource::AS_MINUS = string("-");
@@ -156,6 +158,8 @@ const string ASResource::AS_DYNAMIC_CAST = string("dynamic_cast");
 const string ASResource::AS_REINTERPRET_CAST = string("reinterpret_cast");
 const string ASResource::AS_STATIC_CAST = string("static_cast");
 
+const string ASResource::AS_NS_DURING = string("NS_DURING");
+const string ASResource::AS_NS_HANDLER = string("NS_HANDLER");
 
 /**
  * Sort comparison function.
@@ -404,7 +408,7 @@ void ASResource::buildOperators(vector<const string*>* operators, int fileType)
 	operators->push_back(&AS_ARROW);
 	operators->push_back(&AS_AND);
 	operators->push_back(&AS_OR);
-	operators->push_back(&AS_COLON_COLON);
+	operators->push_back(&AS_SCOPE_RESOLUTION);
 	operators->push_back(&AS_PLUS);
 	operators->push_back(&AS_MINUS);
 	operators->push_back(&AS_MULT);
@@ -522,7 +526,7 @@ void ASResource::buildPreDefinitionHeaders(vector<const string*>* preDefinitionH
 }
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *                             ASBase Funtions
+ *                             ASBase Functions
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 // check if a specific line position contains a keyword.
