@@ -675,6 +675,18 @@ bool CodeGenerator::initIndentationScheme ( const string &indentScheme )
     {
         formatter->setFormattingStyle ( astyle::STYLE_1TBS );
     }
+    else if ( indentScheme=="google")
+    {
+        formatter->setFormattingStyle ( astyle::STYLE_GOOGLE );
+    }
+    else if ( indentScheme=="pico" ||  indentScheme=="a11")
+    {
+        formatter->setFormattingStyle ( astyle::STYLE_PICO );
+    }
+    else if ( indentScheme=="lisp" ||  indentScheme=="python"||  indentScheme=="a12")
+    {
+        formatter->setFormattingStyle ( astyle::STYLE_LISP );
+    } 
     else
     {
         return false;
@@ -1400,14 +1412,19 @@ bool CodeGenerator::processStringState ( State oldState )
     int openDelimID=currentSyntax->getOpenDelimiterID ( token, myState);
     string openDelim=token;
 
+    
+    //Raw String by definition:
+    bool isRawString=currentSyntax->delimiterIsRawString(openDelimID);
+    
     // Test if character before string open delimiter token equals to the
     // raw string prefix (Example: r" ", r""" """ in Python)
-    bool isRawString=currentSyntax->delimiterIsRawString(openDelimID);
+    
+    //Raw String Prefix:
     if ( lineIndex>token.length() &&line[lineIndex-token.length()-1]==currentSyntax->getRawStringPrefix() )
     {
         isRawString=true;
     }
-
+    
     openTag ( myState );
     do
     {
@@ -1442,13 +1459,17 @@ bool CodeGenerator::processStringState ( State oldState )
             printMaskedToken();
             break;
         case ESC_CHAR:
-            if ( !isRawString )
-            {
+            if ( !isRawString ) {
                 closeTag ( myState );
                 eof=processEscapeCharState();
                 openTag ( myState );
                 returnedFromOtherState=true;
-            }
+            } else {
+	        // FIXME not a fix for Python r"""\"""
+	        //exitState=(openDelim=="\"" && token=="\\\""); // C# raw string that ends with '\'
+	        exitState=token.size()>1 && token[1] == openDelim[0];
+	        printMaskedToken();
+	    }
             break;
         case STRING_INTERPOLATION:
             closeTag ( myState );
