@@ -77,8 +77,9 @@ namespace highlight
 		ostringstream os;
 
 		os << "\\documentclass{article}\n"
-		<< "\\usepackage{color}\n"
-		<< "\\usepackage{alltt}\n";
+		    << "\\usepackage{color}\n"
+		    << "\\usepackage{alltt}\n"
+		    << "\\usepackage[T1]{fontenc}\n";
 
 		if ( StringTools::change_case ( encoding ) =="utf-8" )
 		{
@@ -174,6 +175,7 @@ namespace highlight
 		openTags.push_back ( "\\hl"+STY_NAME_DST+"{" );
 		openTags.push_back ( "\\hl"+STY_NAME_LIN+"{" );
 		openTags.push_back ( "\\hl"+STY_NAME_SYM+"{" );
+		openTags.push_back ( "\\hl"+STY_NAME_IPL+"{" );
 
 		for (unsigned int i=0;i<NUMBER_BUILTIN_STATES; i++ )
 		{
@@ -314,6 +316,7 @@ namespace highlight
 			os << getAttributes ( STY_NAME_COM, docStyle.getCommentStyle() );
 			os << getAttributes ( STY_NAME_DIR, docStyle.getPreProcessorStyle() );
 			os << getAttributes ( STY_NAME_SYM, docStyle.getOperatorStyle() );
+			os << getAttributes ( STY_NAME_IPL, docStyle.getInterpolationStyle() );
 			os << getAttributes ( STY_NAME_LIN, docStyle.getLineStyle() );
 
 			KeywordStyles styles = docStyle.getKeywordStyles();
@@ -332,5 +335,4 @@ namespace highlight
 		return styleDefinitionCache;
 	}
 
-
 }
