@@ -57,6 +57,7 @@ namespace highlight
 		openTags.push_back ( getOpenTag ( STY_NAME_DST ) );
 		openTags.push_back ( getOpenTag ( STY_NAME_LIN ) );
 		openTags.push_back ( getOpenTag ( STY_NAME_SYM ) );
+		openTags.push_back ( getOpenTag ( STY_NAME_IPL ) );
 
 		closeTags.push_back ( "" );
 		for (unsigned int i=1;i<NUMBER_BUILTIN_STATES; i++ )
@@ -91,6 +92,7 @@ namespace highlight
 			<< getAttributes ( "tspan."+STY_NAME_COM, docStyle.getCommentStyle() )
 			<< getAttributes ( "tspan."+STY_NAME_DIR, docStyle.getPreProcessorStyle() )
 			<< getAttributes ( "tspan."+STY_NAME_SYM, docStyle.getOperatorStyle() )
+			<< getAttributes ( "tspan."+STY_NAME_IPL, docStyle.getInterpolationStyle() )
 			<< getAttributes ( "tspan."+STY_NAME_LIN, docStyle.getLineStyle() );
 
 			KeywordStyles styles = docStyle.getKeywordStyles();
