@@ -77,13 +77,13 @@ bool ThemeReader::load ( const string &styleDefinitionPath , OutputType type)
 	ls["HL_FORMAT_HTML32"]=HTML32;
 	ls["HL_FORMAT_SVG"]=SVG;
 	ls["HL_FORMAT_BBCODE"]=BBCODE;
+	ls["HL_FORMAT_ODT"]=ODTFLAT;
 	ls["HL_OUTPUT"] = type;
 	ls.doString("Injections={}");
         ls.doFile (styleDefinitionPath);
 
 	desc = ls["Description"].value().asString();
 
-
 	if (pluginChunks.size()){
 	  Diluculum::LuaValueList params;
 	  params.push_back(desc);
@@ -99,6 +99,7 @@ bool ThemeReader::load ( const string &styleDefinitionPath , OutputType type)
         initStyle(directive, ls["PreProcessor"]);
         initStyle(str, ls["String"]);
         initStyle(escapeChar, ls["Escape"]);
+	initStyle(interpolation, ls["Interpolation"]);
         initStyle(number, ls["Number"]);
         initStyle(dstr, ls["StringPreProc"]);
         initStyle(line, ls["LineNum"]);
@@ -114,17 +115,18 @@ bool ThemeReader::load ( const string &styleDefinitionPath , OutputType type)
             idx++;
         }
         
-        idx=1;
+       idx=1;
 	while (ls["Injections"][idx].value() !=Diluculum::Nil) {
-	    injections.push_back (ls["Injections"][idx].value().asString());
-            idx++;
+	  //  injections.push_back (ls["Injections"][idx].value().asString());
+	  themeInjections +=ls["Injections"][idx].value().asString();
+	  idx++;
         }
 
     } catch (Diluculum::LuaFileError err) {
         errorMsg = string(err.what());
         return fileOK=false;
     } catch (Diluculum::TypeMismatchError err) {
-        errorMsg = string(err.what());//expected "+err.getExpectedType()+ ", got "+err.getFoundType();
+        errorMsg = string(err.what());
         return fileOK=false;
     } catch (Diluculum::LuaSyntaxError err) {
         errorMsg = "syntax error: "+string(err.what());
@@ -174,6 +176,12 @@ ElementStyle ThemeReader::getEscapeCharStyle() const
     return escapeChar;
 }
 
+ElementStyle ThemeReader::getInterpolationStyle() const
+{
+    return interpolation;
+}
+
+
 ElementStyle ThemeReader::getNumberStyle() const
 {
     return number;
@@ -221,12 +229,15 @@ KeywordStyles ThemeReader::getKeywordStyles() const
 }
 
 string ThemeReader::getInjections() const{
+  return themeInjections;
+  /*
  ostringstream os;
  for ( vector<string>::const_iterator iter = injections.begin(); iter != injections.end(); iter++ )
     {
         os<<*iter<<"\n";
     }
     return os.str();
+ */
 }
 
 }
