@@ -21,119 +21,116 @@ Installation prüfen.</translation>
 Installation prüfen.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="143"/>
+        <location filename="mainwindow.cpp" line="146"/>
         <source>Select one or more files to open</source>
         <translation>Wähle eine oder mehrere Dateien zum Öffnen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="183"/>
+        <location filename="mainwindow.cpp" line="197"/>
         <source>Select destination directory</source>
         <translation>Wähle das Zielverzeichnis</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="671"/>
         <source>Tags file error</source>
-        <translation>Tags Dateifehler</translation>
+        <translation type="obsolete">Tags Dateifehler</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="672"/>
         <source>Could not read tags information in &quot;%1&quot;</source>
-        <translation>Konnte Tags-Informationen in %1 nicht lesen</translation>
+        <translation type="obsolete">Konnte Tags-Informationen in %1 nicht lesen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="689"/>
-        <location filename="mainwindow.cpp" line="720"/>
+        <location filename="mainwindow.cpp" line="696"/>
+        <location filename="mainwindow.cpp" line="727"/>
         <source>Output error</source>
         <translation>Ausgabefehler</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="689"/>
+        <location filename="mainwindow.cpp" line="696"/>
         <source>Output directory does not exist!</source>
         <translation>Zielverzeichnis existert nicht!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="720"/>
+        <location filename="mainwindow.cpp" line="727"/>
         <source>You must define a style output file!</source>
         <translation>Sie müssen ein Stylesheet zur Ausgabe angeben!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="759"/>
+        <location filename="mainwindow.cpp" line="766"/>
         <source>Language definition error</source>
         <translation>Fehler in Sprachdefinition</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="760"/>
+        <location filename="mainwindow.cpp" line="767"/>
         <source>Invalid regular expression in %1:
 %2</source>
         <translation>Ungültiger regulärer Ausdruck in %1: %2</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="764"/>
+        <location filename="mainwindow.cpp" line="771"/>
         <source>Unknown syntax</source>
         <translation>Unbekannte Syntax</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="764"/>
+        <location filename="mainwindow.cpp" line="771"/>
         <source>Could not convert %1</source>
         <translation>Konnte %1 nicht konvertieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="833"/>
+        <location filename="mainwindow.cpp" line="840"/>
         <source>Converted %1 files in %2 ms</source>
         <translation>%1 Dateien in %2 ms konvertiert</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="918"/>
+        <location filename="mainwindow.cpp" line="925"/>
         <source>Conversion of &quot;%1&quot; not possible.</source>
         <translation>Konnte &quot;%1&quot; nicht konvertieren.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="918"/>
-        <location filename="mainwindow.cpp" line="1022"/>
-        <location filename="mainwindow.cpp" line="1045"/>
+        <location filename="mainwindow.cpp" line="925"/>
+        <location filename="mainwindow.cpp" line="1027"/>
+        <location filename="mainwindow.cpp" line="1050"/>
         <source>clipboard data</source>
         <translation>Daten der Zwischenablage</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="977"/>
+        <location filename="mainwindow.cpp" line="982"/>
         <source>%1 options</source>
         <translation>%1-Optionen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1021"/>
+        <location filename="mainwindow.cpp" line="1026"/>
         <source>Preview (%1):</source>
         <translation>Vorschau (%1):</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1024"/>
+        <location filename="mainwindow.cpp" line="1029"/>
         <source>Current syntax: %1</source>
         <translation>Aktuelle Syntax: %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1045"/>
+        <location filename="mainwindow.cpp" line="1050"/>
         <source>Preview of &quot;%1&quot; not possible.</source>
         <translation>Vorschau von &quot;%1&quot; nicht möglich.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1056"/>
         <source>Choose a ctags file</source>
-        <translation>Wählen Sie eine ctags Datei</translation>
+        <translation type="obsolete">Wählen Sie eine ctags Datei</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1082"/>
-        <location filename="mainwindow.cpp" line="1086"/>
-        <location filename="mainwindow.cpp" line="1090"/>
-        <location filename="mainwindow.cpp" line="1095"/>
+        <location filename="mainwindow.cpp" line="1081"/>
+        <location filename="mainwindow.cpp" line="1085"/>
+        <location filename="mainwindow.cpp" line="1089"/>
+        <location filename="mainwindow.cpp" line="1094"/>
         <source>Choose a style include file</source>
         <translation>Wählen Sie ein Eingabe-Stylesheet</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1100"/>
+        <location filename="mainwindow.cpp" line="1099"/>
         <source>About providing translations</source>
         <translation>Übersetzungen bereitstellen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1101"/>
+        <location filename="mainwindow.cpp" line="1100"/>
         <source>The GUI was developed using the Qt toolkit, and translations may be provided using the tools Qt Linguist and lrelease.
 The highlight.ts file for Linguist resides in the src/gui-qt subdirectory.
 The qm file generated by lrelease has to be saved in gui-files/l10n.
@@ -146,12 +143,12 @@ Die von lrelease ausgegebene qm-Datei wird in gui-files/l10n gespeichert.
 Bitte senden Sie eine Nachricht an as (at) andre-simon (dot) de, wenn Sie Probleme bei der Übersetzung haben oder wenn Sie eine Übersetzung fertiggestellt bzw. aktualisiert haben.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1158"/>
+        <location filename="mainwindow.cpp" line="1160"/>
         <source>Select one or more plug-ins</source>
         <translation>Wähle ein Plug-in</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1211"/>
+        <location filename="mainwindow.cpp" line="1212"/>
         <source>Choose a plug-in input file</source>
         <translation>Wähle eine Eingabedatei für Plug-Ins aus</translation>
     </message>
@@ -213,10 +210,9 @@ Bitte senden Sie eine Nachricht an as (at) andre-simon (dot) de, wenn Sie Proble
         <location filename="mainwindow.ui" line="293"/>
         <location filename="mainwindow.ui" line="553"/>
         <location filename="mainwindow.ui" line="1022"/>
-        <location filename="mainwindow.ui" line="1133"/>
-        <location filename="mainwindow.ui" line="1346"/>
-        <location filename="mainwindow.ui" line="1442"/>
-        <location filename="mainwindow.ui" line="1678"/>
+        <location filename="mainwindow.ui" line="1269"/>
+        <location filename="mainwindow.ui" line="1365"/>
+        <location filename="mainwindow.ui" line="1601"/>
         <source>...</source>
         <translation>...</translation>
     </message>
@@ -437,15 +433,15 @@ Das Encoding muss mit den Eingabedateien übereinstimmen.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="945"/>
-        <location filename="mainwindow.ui" line="1276"/>
-        <location filename="mainwindow.ui" line="1372"/>
-        <location filename="mainwindow.ui" line="1608"/>
+        <location filename="mainwindow.ui" line="1199"/>
+        <location filename="mainwindow.ui" line="1295"/>
+        <location filename="mainwindow.ui" line="1531"/>
         <source>Include the style information in each output file.</source>
         <translation>Füge die Stylesheets in jede Ausgabedatei ein.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="948"/>
-        <location filename="mainwindow.ui" line="1611"/>
+        <location filename="mainwindow.ui" line="1534"/>
         <source>Embed style (CSS)</source>
         <translation>CSS einbetten</translation>
     </message>
@@ -465,14 +461,14 @@ Das Encoding muss mit den Eingabedateien übereinstimmen.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="991"/>
-        <location filename="mainwindow.ui" line="1394"/>
-        <location filename="mainwindow.ui" line="1630"/>
+        <location filename="mainwindow.ui" line="1317"/>
+        <location filename="mainwindow.ui" line="1553"/>
         <source>Name of the referenced style file.</source>
         <translation>Name des  referenzierten Stylesheets.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="994"/>
-        <location filename="mainwindow.ui" line="1633"/>
+        <location filename="mainwindow.ui" line="1556"/>
         <source>highlight.css</source>
         <translation></translation>
     </message>
@@ -482,7 +478,7 @@ Das Encoding muss mit den Eingabedateien übereinstimmen.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="1012"/>
-        <location filename="mainwindow.ui" line="1668"/>
+        <location filename="mainwindow.ui" line="1591"/>
         <source>Path of the CSS include file.</source>
         <translation>Pfad zur CSS-Datei, die ins Stylesheet eingefügt werden soll.</translation>
     </message>
@@ -506,20 +502,19 @@ Das Encoding muss mit den Eingabedateien übereinstimmen.</translation>
         <translation type="obsolete">Tags- und Indexdateien</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1075"/>
+        <location filename="mainwindow.ui" line="1118"/>
         <source>Generate an index file with hyperlinks to all outputted files.</source>
         <translation>Erzeuge eine Indexdatei mit Links zu allen Ausgabedateien.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1078"/>
+        <location filename="mainwindow.ui" line="1121"/>
         <source>Generate index file</source>
         <translation>Indexdatei erzeugen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1098"/>
         <source>Read a ctags file and add the included metainformation as tooltips.
 See ctags.sf.net for details.</source>
-        <translation>Lese eine ctags-Datei und füge die Metainformationen als Tooltips hinzu.
+        <translation type="obsolete">Lese eine ctags-Datei und füge die Metainformationen als Tooltips hinzu.
 Siehe ctags.sf.net um mehr darüber zu erfahren.</translation>
     </message>
     <message>
@@ -527,42 +522,40 @@ Siehe ctags.sf.net um mehr darüber zu erfahren.</translation>
         <translation type="obsolete">Ctags Datei:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1117"/>
         <source>Path of the ctags file.</source>
-        <translation>Pfad der ctags-Datei.</translation>
+        <translation type="obsolete">Pfad der ctags-Datei.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1130"/>
         <source>Choose a ctags file.</source>
-        <translation>Wähle eine ctags Datei.</translation>
+        <translation type="obsolete">Wähle eine ctags Datei.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1159"/>
+        <location filename="mainwindow.ui" line="1069"/>
         <source>Misc</source>
         <translation>Verschiedenes</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1178"/>
+        <location filename="mainwindow.ui" line="1088"/>
         <source>Add an achor to each line.</source>
         <translation>Füge Anker zu jeder Zeile hinzu.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1181"/>
+        <location filename="mainwindow.ui" line="1091"/>
         <source>Add line anchors</source>
         <translation>Anker einfügen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1188"/>
+        <location filename="mainwindow.ui" line="1098"/>
         <source>Add the filename as prefix to the anchors.</source>
         <translation>Füge Dateinamen als Präfix zum Anker hinzu.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1191"/>
+        <location filename="mainwindow.ui" line="1101"/>
         <source>Include file name in anchor</source>
         <translation>Dateiname im Anker</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1198"/>
+        <location filename="mainwindow.ui" line="1108"/>
         <source>Output the lines within an ordered list.</source>
         <translation>Gib die Zeilen als sortierte Liste aus.</translation>
     </message>
@@ -571,7 +564,7 @@ Siehe ctags.sf.net um mehr darüber zu erfahren.</translation>
         <translation type="obsolete">Sortierte Liste</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1215"/>
+        <location filename="mainwindow.ui" line="1128"/>
         <source>Add &amp;lt;pre&amp;gt; tags to the output, if the flag &quot;No document header and footer&quot; is selected.</source>
         <translation>Schließe die Ausgabe in  &amp;lt;pre&amp;gt;-Tags ein, wenn die Option &quot;Kopf- und Fußteil auslassen&quot; gewählt ist.</translation>
     </message>
@@ -584,17 +577,17 @@ Siehe ctags.sf.net um mehr darüber zu erfahren.</translation>
         <translation type="obsolete">LaTeX Optionen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1246"/>
+        <location filename="mainwindow.ui" line="1169"/>
         <source>Replace quotes by dq sequences.</source>
         <translation>Ersetze Anführungszeichen mit \dq-Sequenzen.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1249"/>
+        <location filename="mainwindow.ui" line="1172"/>
         <source>Escape quotes</source>
         <translation>Ersetze Anführungszeichen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1256"/>
+        <location filename="mainwindow.ui" line="1179"/>
         <source>Make output Babel compatible.</source>
         <translation>Erzeuge Code, der mit Babel verträglich ist.</translation>
     </message>
@@ -603,7 +596,7 @@ Siehe ctags.sf.net um mehr darüber zu erfahren.</translation>
         <translation type="obsolete">Babel Kompatibilität</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1266"/>
+        <location filename="mainwindow.ui" line="1189"/>
         <source>Replace default symbols (brackets, tilde) by nice redefinitions.</source>
         <translation>Ersetze Standard-Darstellung verschiedener Symbole (Klammern, Tilde) durch schönere Definitionen.</translation>
     </message>
@@ -612,18 +605,18 @@ Siehe ctags.sf.net um mehr darüber zu erfahren.</translation>
         <translation type="obsolete">Schönere Symbole</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1279"/>
+        <location filename="mainwindow.ui" line="1202"/>
         <source>Embed style (defs)</source>
         <translation>Stylesheet einbetten</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1298"/>
+        <location filename="mainwindow.ui" line="1221"/>
         <source>Name of the referenced  style file.</source>
         <translation>Name des  referenzierten Stylesheets.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1301"/>
-        <location filename="mainwindow.ui" line="1397"/>
+        <location filename="mainwindow.ui" line="1224"/>
+        <location filename="mainwindow.ui" line="1320"/>
         <source>highlight.sty</source>
         <translation></translation>
     </message>
@@ -637,35 +630,34 @@ Siehe ctags.sf.net um mehr darüber zu erfahren.</translation>
         <translation>Encoding:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1102"/>
         <source>Read ctags file:</source>
-        <translation>Lese ctags-Datei:</translation>
+        <translation type="obsolete">Lese ctags-Datei:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1201"/>
+        <location filename="mainwindow.ui" line="1111"/>
         <source>Output as ordered list</source>
         <translation>Sortierte Liste</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1218"/>
+        <location filename="mainwindow.ui" line="1131"/>
         <source>Enclose in pre tags</source>
         <translation>Schließe in pre-Tags  ein</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1259"/>
+        <location filename="mainwindow.ui" line="1182"/>
         <source>Add Babel compatibility</source>
         <translation>Babel Kompatibilität</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1269"/>
+        <location filename="mainwindow.ui" line="1192"/>
         <source>Add pretty symbols</source>
         <translation>Symbole anpassen</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="978"/>
-        <location filename="mainwindow.ui" line="1288"/>
-        <location filename="mainwindow.ui" line="1384"/>
-        <location filename="mainwindow.ui" line="1620"/>
+        <location filename="mainwindow.ui" line="1211"/>
+        <location filename="mainwindow.ui" line="1307"/>
+        <location filename="mainwindow.ui" line="1543"/>
         <source>Stylesheet file:</source>
         <translation>Stylesheet-Datei:</translation>
     </message>
@@ -675,14 +667,14 @@ Siehe ctags.sf.net um mehr darüber zu erfahren.</translation>
         <translation>Zielverzeichnis:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1312"/>
-        <location filename="mainwindow.ui" line="1408"/>
-        <location filename="mainwindow.ui" line="1644"/>
+        <location filename="mainwindow.ui" line="1235"/>
+        <location filename="mainwindow.ui" line="1331"/>
+        <location filename="mainwindow.ui" line="1567"/>
         <source>Stylesheet include file:</source>
         <translation>Eingabe-Stylesheet:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1171"/>
+        <location filename="mainwindow.ui" line="1081"/>
         <source>Line numbering options:</source>
         <translation>Optionen der Zeilennummerierung:</translation>
     </message>
@@ -784,20 +776,19 @@ p, li { white-space: pre-wrap; }
         <translation>Eingabedatei:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1069"/>
         <source>Index/ctags</source>
-        <translation>Index/ctags</translation>
+        <translation type="obsolete">Index/ctags</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1336"/>
-        <location filename="mainwindow.ui" line="1432"/>
+        <location filename="mainwindow.ui" line="1259"/>
+        <location filename="mainwindow.ui" line="1355"/>
         <source>Path of the style include file.</source>
         <translation>Pfad zur sty-Datei, die ins Stylesheet eingefügt werden soll.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1343"/>
-        <location filename="mainwindow.ui" line="1439"/>
-        <location filename="mainwindow.ui" line="1675"/>
+        <location filename="mainwindow.ui" line="1266"/>
+        <location filename="mainwindow.ui" line="1362"/>
+        <location filename="mainwindow.ui" line="1598"/>
         <source>Select a style include file.</source>
         <translation>Wähle eine Stylesheet-Eingabedatei.</translation>
     </message>
@@ -806,7 +797,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">TeX Optionen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1375"/>
+        <location filename="mainwindow.ui" line="1298"/>
         <source>Embed style (macros)</source>
         <translation>Stylesheet einbetten</translation>
     </message>
@@ -815,64 +806,64 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">RTF Optionen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1468"/>
+        <location filename="mainwindow.ui" line="1391"/>
         <source>Add character stylesheets with formatting information.
 You can select the stylesheets in your word processor to reformat additional text.</source>
         <translation>Füge Zeichenvorlagen mit Formatierungsinformationen hinzu.
 Diese können in der Textverarbeitung gewählt werden, um zusätzlichen Text zu formatieren.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1472"/>
+        <location filename="mainwindow.ui" line="1395"/>
         <source>Add character styles</source>
         <translation>Zeichenvorlagen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1481"/>
+        <location filename="mainwindow.ui" line="1404"/>
         <source>Page size:</source>
         <translation>Papierformat:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1488"/>
+        <location filename="mainwindow.ui" line="1411"/>
         <source>Select a page size.</source>
         <translation>Wähle eine Seitengröße aus.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1495"/>
+        <location filename="mainwindow.ui" line="1418"/>
         <source>A3</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1500"/>
+        <location filename="mainwindow.ui" line="1423"/>
         <source>A4</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1505"/>
+        <location filename="mainwindow.ui" line="1428"/>
         <source>A5</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1510"/>
+        <location filename="mainwindow.ui" line="1433"/>
         <source>B4</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1515"/>
+        <location filename="mainwindow.ui" line="1438"/>
         <source>B5</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1520"/>
+        <location filename="mainwindow.ui" line="1443"/>
         <source>B6</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1525"/>
+        <location filename="mainwindow.ui" line="1448"/>
         <source>Letter</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1530"/>
+        <location filename="mainwindow.ui" line="1453"/>
         <source>Legal</source>
         <translation></translation>
     </message>
@@ -881,186 +872,186 @@ Diese können in der Textverarbeitung gewählt werden, um zusätzlichen Text zu
         <translation type="obsolete">SVG Optionen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1557"/>
+        <location filename="mainwindow.ui" line="1480"/>
         <source>Image size:</source>
         <translation>Bildgröße:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1566"/>
+        <location filename="mainwindow.ui" line="1489"/>
         <source>Width:</source>
         <translation>Breite:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1582"/>
+        <location filename="mainwindow.ui" line="1505"/>
         <source>Enter the SVG width (may contain units).</source>
         <translation>Gib die Bildbreite ein (kann Größeneinheiten enthalten).</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1589"/>
+        <location filename="mainwindow.ui" line="1512"/>
         <source>Height:</source>
         <translation>Höhe:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1599"/>
+        <location filename="mainwindow.ui" line="1522"/>
         <source>Enter the SVG height (may contain units).</source>
         <translation>Gib die Bildhöhe ein (kann Größeneinheiten enthalten).</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1704"/>
+        <location filename="mainwindow.ui" line="1627"/>
         <source>No options defined.</source>
         <translation>Keine Optionen vorhanden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1729"/>
+        <location filename="mainwindow.ui" line="1652"/>
         <source>Formatting</source>
         <translation>Formatierung</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1743"/>
+        <location filename="mainwindow.ui" line="1666"/>
         <source>Color theme:</source>
         <translation>Farbschema:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1759"/>
+        <location filename="mainwindow.ui" line="1682"/>
         <source>Select a colour theme.</source>
         <translation>Wähle ein Farbschema.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1770"/>
+        <location filename="mainwindow.ui" line="1693"/>
         <source>Reformat and indent your code.
 This feature is enabled tor C, C++, C# and Java code.</source>
         <translation>Formatiere den Eingabecode.
 Diese Funktion kann auf C, C++, C# und Java-Code angewandt werden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1774"/>
+        <location filename="mainwindow.ui" line="1697"/>
         <source>Reformat:</source>
         <translation>Formatieren:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1787"/>
+        <location filename="mainwindow.ui" line="1710"/>
         <source>Choose a formatting scheme.</source>
         <translation>Wähle ein Formatierungs-Schema.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1791"/>
+        <location filename="mainwindow.ui" line="1714"/>
         <source>Allman</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1796"/>
+        <location filename="mainwindow.ui" line="1719"/>
         <source>Banner</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1801"/>
+        <location filename="mainwindow.ui" line="1724"/>
         <source>GNU</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1806"/>
+        <location filename="mainwindow.ui" line="1729"/>
         <source>Horstmann</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1811"/>
+        <location filename="mainwindow.ui" line="1734"/>
         <source>Java</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1816"/>
+        <location filename="mainwindow.ui" line="1739"/>
         <source>K&amp;R</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1821"/>
+        <location filename="mainwindow.ui" line="1744"/>
         <source>Linux</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1826"/>
+        <location filename="mainwindow.ui" line="1749"/>
         <source>OTBS</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1831"/>
+        <location filename="mainwindow.ui" line="1754"/>
         <source>Stroustrup</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1836"/>
+        <location filename="mainwindow.ui" line="1759"/>
         <source>Whitesmith</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1848"/>
+        <location filename="mainwindow.ui" line="1771"/>
         <source>Change the keyword case.</source>
         <translation>Ändere die Groß- und Kleinschreibung, wenn die Eingabesyntax nicht case-sensitive ist.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1851"/>
+        <location filename="mainwindow.ui" line="1774"/>
         <source>Keyword case:</source>
         <translation>Schlüsselwort Case:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1864"/>
+        <location filename="mainwindow.ui" line="1787"/>
         <source>Select a keyword case.</source>
         <translation>Wähle einen Typ der Groß- und Kleinschreibung.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1868"/>
+        <location filename="mainwindow.ui" line="1791"/>
         <source>UPPER</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1873"/>
+        <location filename="mainwindow.ui" line="1796"/>
         <source>lower</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1878"/>
+        <location filename="mainwindow.ui" line="1801"/>
         <source>Capitalize</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1896"/>
+        <location filename="mainwindow.ui" line="1819"/>
         <source>Tab width:</source>
         <translation>Tabulatorbreite:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1906"/>
+        <location filename="mainwindow.ui" line="1829"/>
         <source>Enter the number of spaces which replace a tab.
 Set the width to 0 to keep tabs.</source>
         <translation>Gib die Anzahl der Leerzeichen an, die ein Tab ersetzen.
 Setze die Anzahl auf Null, um Tabs auszugeben.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1921"/>
+        <location filename="mainwindow.ui" line="1846"/>
         <source>Enable line wrapping.</source>
         <translation>Aktiviere den automatischen Zeilenumbruch.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1924"/>
+        <location filename="mainwindow.ui" line="1849"/>
         <source>Line wrapping</source>
         <translation>Zeilenumbruch</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1931"/>
+        <location filename="mainwindow.ui" line="1854"/>
         <source>Enter the maximum line length.</source>
         <translation>Gib die maximale Zeilenlänge ein.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1950"/>
+        <location filename="mainwindow.ui" line="1882"/>
         <source>Indent statements and function parameters after wrapping.</source>
         <translation>Rücke Kommandos und Funktionsparameter nach dem Umbruch ein.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1953"/>
+        <location filename="mainwindow.ui" line="1885"/>
         <source>Intelligent wrapping</source>
         <translation>Intelligenter Umbruch</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1987"/>
+        <location filename="mainwindow.ui" line="1911"/>
         <source>Font name:</source>
         <translation>Schriftart:</translation>
     </message>
@@ -1069,22 +1060,22 @@ Setze die Anzahl auf Null, um Tabs auszugeben.</translation>
         <translation type="obsolete">Wähle oder gib die Schriftart an.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2014"/>
+        <location filename="mainwindow.ui" line="1938"/>
         <source>Font size:</source>
         <translation>Schriftgröße:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2030"/>
+        <location filename="mainwindow.ui" line="1954"/>
         <source>Enter the font size.</source>
         <translation>Gib die Schriftgröße ein.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2103"/>
+        <location filename="mainwindow.ui" line="2027"/>
         <source>Visit andre-simon.de</source>
         <translation>Besuche andre-simon.de</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2114"/>
+        <location filename="mainwindow.ui" line="2038"/>
         <source>&amp;Dock floating panels</source>
         <translation>&amp;Schwebende Fenster andocken</translation>
     </message>
@@ -1202,62 +1193,83 @@ Setze die Anzahl auf Null, um Tabs auszugeben.</translation>
         <translation>Wähle eine Plug-In Eingabedatei.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2002"/>
+        <location filename="mainwindow.ui" line="1138"/>
+        <source>Replace spaces by nbsp entities.</source>
+        <oldsource>Replace spaces by &amp;nbsp; entities.</oldsource>
+        <translation>Ersetze Leerzeichen durch nbsp-Codes.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1141"/>
+        <source>Use non breaking spaces</source>
+        <translation>Benutze geschützte Leerzeichen</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1890"/>
+        <source>Do not add line numbering to lines which were automatically wrapped.</source>
+        <translation>Gib bei automatisch umgebrochenen Zeilen keine Nummerierung aus.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1893"/>
+        <source>Omit line numbers of wrapped lines</source>
+        <translation>Keine Nummerierung bei Umbruch</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1926"/>
         <source>Select or enter the font name. HTML supports a list of fonts, separated with comma.</source>
         <translation>Wähle oder gib den Fontnamen ein. HTML unterstützt auch eine mit Komma getrennte Liste von Fonts.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2045"/>
+        <location filename="mainwindow.ui" line="1969"/>
         <source>&amp;Open files</source>
         <translation>Öffne &amp;Dateien</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2050"/>
+        <location filename="mainwindow.ui" line="1974"/>
         <source>&amp;Exit</source>
         <translation>&amp;Beenden</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2055"/>
+        <location filename="mainwindow.ui" line="1979"/>
         <source>&amp;Load</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2060"/>
+        <location filename="mainwindow.ui" line="1984"/>
         <source>&amp;Save</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2065"/>
+        <location filename="mainwindow.ui" line="1989"/>
         <source>Load &amp;default project</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2070"/>
+        <location filename="mainwindow.ui" line="1994"/>
         <source>Readme</source>
         <translation>Handbuch</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2075"/>
+        <location filename="mainwindow.ui" line="1999"/>
         <source>&amp;Tips</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2083"/>
+        <location filename="mainwindow.ui" line="2007"/>
         <source>&amp;Changelog</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2088"/>
+        <location filename="mainwindow.ui" line="2012"/>
         <source>&amp;License</source>
         <translation>&amp;Lizenz</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2093"/>
+        <location filename="mainwindow.ui" line="2017"/>
         <source>&amp;About Highlight</source>
         <translation>&amp;Über Highlight</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2098"/>
+        <location filename="mainwindow.ui" line="2022"/>
         <source>About &amp;translations</source>
         <translation>&amp;Infos zu Übersetzungen</translation>
     </message>
