@@ -32,6 +32,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "ui_mainwindow.h"
 #include "version.h"
 #include "showtextfile.h"
+
 #include "io_report.h"
 
 //#undef DATA_DIR
@@ -81,6 +82,12 @@ MainWindow::MainWindow(QWidget *parent)
     }
     ui->comboTheme->setCurrentIndex(0);
 
+    //does not work in GUI editor when adding > 10 items ?!?
+    QStringList fmts;
+    fmts << "Allman" << "Banner" << "GNU" <<"Google"<< "Horstmann"<<"Lisp"<<"Java"<<"K&R"<<"Linux"<<"OTBS"<<"Pico"<<"Stroustrup"<<"Whitesmith";
+    ui->comboReformat->clear();
+    ui->comboReformat->addItems(fmts);
+
     // load syntax mappings
    if (!loadFileTypeConfig(&extensions, &shebangs)){
      QMessageBox::warning(this, tr("Initialization error"),
@@ -475,8 +482,13 @@ string MainWindow::getFileType(const string& suffix, const string &inputFile)
 string MainWindow::getFileSuffix(const string& fileName)
 {
   size_t ptPos=fileName.rfind(".");
-  return (ptPos == string::npos) ? "" : fileName.substr(ptPos+1,
-                                        fileName.length());
+  size_t psPos = fileName.rfind ( Platform::pathSeparator );
+  
+  if (ptPos == string::npos){
+     return  (psPos==string::npos) ? fileName : fileName.substr(psPos+1, fileName.length());
+  }
+  //return  fileName.substr(ptPos+1, fileName.length());
+  return (psPos!=string::npos && psPos>ptPos) ? "" : fileName.substr(ptPos+1, fileName.length());
 }
 
 /*
@@ -1066,6 +1078,8 @@ void MainWindow::on_action_License_triggered()
     show.exec();
 }
 
+
+
 void MainWindow::on_pbHTMLChooseStyleIncFile_clicked()
 {
         selectSingleFile(ui->leHTMLStyleIncFile, tr("Choose a style include file"), "*.css");
