@@ -26,20 +26,34 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+#include <QtGlobal>
+
+#if (QT_VERSION < QT_VERSION_CHECK(5,0,0))
 #include <QtGui/QMainWindow>
 #include <QtGui/QMessageBox>
 #include <QtGui/QFileDialog>
 #include <QtGui/QListWidget>
+#include <QLineEdit>
+#include <QScrollBar>
+#include <QDropEvent>
+#else
+#include <QtWidgets/QMainWindow>
+#include <QtWidgets/QMessageBox>
+#include <QtWidgets/QFileDialog>
+#include <QtWidgets/QListWidget>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QScrollBar>
+#include <QDropEvent>
+#endif
 #include <QSettings>
 #include <QDir>
 #include <QClipboard>
 #include <QMimeData>
 #include <QTime>
-#include <QLineEdit>
+
 #include <QString>
 #include <QTextStream>
-#include <QScrollBar>
-#include <QDropEvent>
+
 #include <QDesktopServices>
 
 #include "version.h"
@@ -103,7 +117,7 @@ public slots:
     void on_pbCopyFile2CP_clicked();
 
 private slots:
-    void on_lvPluginScripts_itemClicked(QListWidgetItem* item);
+
     void on_actionVisit_website_triggered();
     void on_pbClearAllPlugins_clicked();
     void on_pbClearAll_clicked();
@@ -120,7 +134,6 @@ private slots:
     void on_action_License_triggered();
     void on_action_Changelog_triggered();
     void on_action_Manual_triggered();
-    void on_pbHTMLChooseTagsFile_clicked();
     void on_action_About_Highlight_triggered();
     void on_action_Exit_triggered();
     void plausibility();
@@ -129,6 +142,8 @@ private slots:
 
     void on_actionDock_floating_panels_toggled(bool arg1);
     void on_pbPluginReadFilePath_clicked();
+
+    void on_lvPluginScripts_currentRowChanged(int currentRow);
 };
 
 #endif // MAINWINDOW_H
