@@ -22,31 +22,28 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include <string>
 #include <iostream>
 #include <vector>
-/*
-#ifdef USE_FN_MATCH
-  #include <fnmatch.h>
-#endif
-*/
 
 namespace Platform
-{
-	extern const char pathSeparator;
+  {
+  extern const char pathSeparator;
 
-	std::string getAppPath();
+  std::string getAppPath();
 
-	/** \param fileList Vector where found entries will be stored
-	    \param  wildcard Directory path and wildcard
-	    \param recursiveSearch Test if directory should be searched recursively */
-	bool getDirectoryEntries ( std::vector<std::string> &fileList,
-	                           std::string wildcard,
-	                           bool recursiveSearch=false );
+  std::string getHomePath();
 
-	void getFileNames ( const std::string &directory,const std::string &wildcard,
-	                    std::vector<std::string> &fileName );
+  /** \param fileList Vector where found entries will be stored
+      \param  wildcard Directory path and wildcard
+      \param recursiveSearch Test if directory should be searched recursively */
+  bool getDirectoryEntries ( std::vector<std::string> &fileList,
+			    std::string wildcard,
+			    bool recursiveSearch=false );
 
-	int wildcmp ( const char *wild, const char *data );
+  void getFileNames ( const std::string &directory,const std::string &wildcard,
+		      std::vector<std::string> &fileName );
 
-	bool fileExists(const std::string &fName);
+  int wildcmp ( const char *wild, const char *data );
 
+  bool fileExists(const std::string &fName);
 }
 #endif
+
